diff libpurple/debug.h @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 6dc5dc83a61b
line wrap: on
line diff
--- a/libpurple/debug.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/debug.h	Mon Mar 19 07:01:17 2007 +0000
@@ -2,9 +2,9 @@
  * @file debug.h Debug API
  * @ingroup core
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -22,8 +22,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#ifndef _GAIM_DEBUG_H_
-#define _GAIM_DEBUG_H_
+#ifndef _PURPLE_DEBUG_H_
+#define _PURPLE_DEBUG_H_
 
 #include <glib.h>
 #include <stdarg.h>
@@ -33,23 +33,23 @@
  */
 typedef enum
 {
-	GAIM_DEBUG_ALL = 0,  /**< All debug levels.              */
-	GAIM_DEBUG_MISC,     /**< General chatter.               */
-	GAIM_DEBUG_INFO,     /**< General operation Information. */
-	GAIM_DEBUG_WARNING,  /**< Warnings.                      */
-	GAIM_DEBUG_ERROR,    /**< Errors.                        */
-	GAIM_DEBUG_FATAL     /**< Fatal errors.                  */
+	PURPLE_DEBUG_ALL = 0,  /**< All debug levels.              */
+	PURPLE_DEBUG_MISC,     /**< General chatter.               */
+	PURPLE_DEBUG_INFO,     /**< General operation Information. */
+	PURPLE_DEBUG_WARNING,  /**< Warnings.                      */
+	PURPLE_DEBUG_ERROR,    /**< Errors.                        */
+	PURPLE_DEBUG_FATAL     /**< Fatal errors.                  */
 
-} GaimDebugLevel;
+} PurpleDebugLevel;
 
 /**
  * Debug UI operations.
  */
 typedef struct
 {
-	void (*print)(GaimDebugLevel level, const char *category,
+	void (*print)(PurpleDebugLevel level, const char *category,
 				  const char *arg_s);
-} GaimDebugUiOps;
+} PurpleDebugUiOps;
 
 #ifdef __cplusplus
 extern "C" {
@@ -65,87 +65,87 @@
  * @param category The category (or @c NULL).
  * @param format   The format string.
  */
-void gaim_debug(GaimDebugLevel level, const char *category,
+void purple_debug(PurpleDebugLevel level, const char *category,
 				const char *format, ...);
 
 /**
  * Outputs misc. level debug information.
  *
  * This is a wrapper for gaim_debug(), and uses GAIM_DEBUG_MISC as
  * the level.
  *
  * @param category The category (or @c NULL).
  * @param format   The format string.
  *
- * @see gaim_debug()
+ * @see purple_debug()
  */
-void gaim_debug_misc(const char *category, const char *format, ...);
+void purple_debug_misc(const char *category, const char *format, ...);
 
 /**
  * Outputs info level debug information.
  *
  * This is a wrapper for gaim_debug(), and uses GAIM_DEBUG_INFO as
  * the level.
  *
  * @param category The category (or @c NULL).
  * @param format   The format string.
  *
- * @see gaim_debug()
+ * @see purple_debug()
  */
-void gaim_debug_info(const char *category, const char *format, ...);
+void purple_debug_info(const char *category, const char *format, ...);
 
 /**
  * Outputs warning level debug information.
  *
  * This is a wrapper for gaim_debug(), and uses GAIM_DEBUG_WARNING as
  * the level.
  *
  * @param category The category (or @c NULL).
  * @param format   The format string.
  *
- * @see gaim_debug()
+ * @see purple_debug()
  */
-void gaim_debug_warning(const char *category, const char *format, ...);
+void purple_debug_warning(const char *category, const char *format, ...);
 
 /**
  * Outputs error level debug information.
  *
  * This is a wrapper for gaim_debug(), and uses GAIM_DEBUG_ERROR as
  * the level.
  *
  * @param category The category (or @c NULL).
  * @param format   The format string.
  *
- * @see gaim_debug()
+ * @see purple_debug()
  */
-void gaim_debug_error(const char *category, const char *format, ...);
+void purple_debug_error(const char *category, const char *format, ...);
 
 /**
  * Outputs fatal error level debug information.
  *
  * This is a wrapper for gaim_debug(), and uses GAIM_DEBUG_ERROR as
  * the level.
  *
  * @param category The category (or @c NULL).
  * @param format   The format string.
  *
- * @see gaim_debug()
+ * @see purple_debug()
  */
-void gaim_debug_fatal(const char *category, const char *format, ...);
+void purple_debug_fatal(const char *category, const char *format, ...);
 
 /**
  * Enable or disable printing debug output to the console.
  *
  * @param enabled TRUE to enable debug output or FALSE to disable it.
  */
-void gaim_debug_set_enabled(gboolean enabled);
+void purple_debug_set_enabled(gboolean enabled);
 
 /**
  * Check if console debug output is enabled.
  *
  * @return TRUE if debuggin is enabled, FALSE if it is not.
  */
-gboolean gaim_debug_is_enabled(void);
+gboolean purple_debug_is_enabled(void);
 
 /*@}*/
 
@@ -160,7 +160,7 @@
  *
  * @param ops The UI operations structure.
  */
-void gaim_debug_set_ui_ops(GaimDebugUiOps *ops);
+void purple_debug_set_ui_ops(PurpleDebugUiOps *ops);
 
 /**
  * Returns the UI operations structure used when outputting debug
@@ -168,7 +168,7 @@
  *
  * @return The UI operations structure in use.
  */
-GaimDebugUiOps *gaim_debug_get_ui_ops(void);
+PurpleDebugUiOps *purple_debug_get_ui_ops(void);
 
 /*@}*/
 
@@ -180,7 +180,7 @@
 /**
  * Initializes the debug subsystem.
  */
-void gaim_debug_init(void);
+void purple_debug_init(void);
 
 /*@}*/
 
@@ -188,4 +188,4 @@
 }
 #endif
 
-#endif /* _GAIM_DEBUG_H_ */
+#endif /* _PURPLE_DEBUG_H_ */
@@ -2,9 +2,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
@@ -65,87 +65,87 @@
  * Outputs misc. level debug information.
  *
- * This is a wrapper for gaim_debug(), and uses GAIM_DEBUG_MISC as
+ * This is a wrapper for purple_debug(), and uses PURPLE_DEBUG_MISC as
  * the level.
  *
@@ -65,87 +65,87 @@
  * Outputs info level debug information.
  *
- * This is a wrapper for gaim_debug(), and uses GAIM_DEBUG_INFO as
+ * This is a wrapper for purple_debug(), and uses PURPLE_DEBUG_INFO as
  * the level.
  *
@@ -65,87 +65,87 @@
  * Outputs warning level debug information.
  *
- * This is a wrapper for gaim_debug(), and uses GAIM_DEBUG_WARNING as
+ * This is a wrapper for purple_debug(), and uses PURPLE_DEBUG_WARNING as
  * the level.
  *
@@ -65,87 +65,87 @@
  * Outputs error level debug information.
  *
- * This is a wrapper for gaim_debug(), and uses GAIM_DEBUG_ERROR as
+ * This is a wrapper for purple_debug(), and uses PURPLE_DEBUG_ERROR as
  * the level.
  *
@@ -65,87 +65,87 @@
  * Outputs fatal error level debug information.
  *
- * This is a wrapper for gaim_debug(), and uses GAIM_DEBUG_ERROR as
+ * This is a wrapper for purple_debug(), and uses PURPLE_DEBUG_ERROR as
  * the level.
  *